        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
}
