        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,2,11,12,13,14,16,18,19,20,22,24,27,28,32,33,35,36,38,42,46,49,50';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 14 <br>1,4,5,6,7,8,10,23,26,30,31,34,40,41';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260514 a 00</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>3,9,15,17,21,25,29,37,39,43,44,45,47,48';}
}
